==> akregator-17.04.3.tar.xz: akregator-17.04.3/src/subscription/subscriptionlistjobs.h <==
/*
    This file is part of Akregator.

    Copyright (C) 2008 Frank Osterfeld <osterfeld@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

    As a special exception, permission is given to link this program
    with any edition of Qt, and distribute the resulting executable,
    without including the source code for Qt in the source distribution.
*/

#ifndef AKREGATOR_SUBSCRIPTIONLISTJOBS_H
#define AKREGATOR_SUBSCRIPTIONLISTJOBS_H

#include <KJob>

#include <QWeakPointer>

#include "akregator_export.h"

namespace Akregator
{

class FeedList;

//transitional job classes

class AKREGATOR_EXPORT  MoveSubscriptionJob : public KJob
{
    Q_OBJECT
public:
    explicit MoveSubscriptionJob(QObject *parent = nullptr);

    void setSubscriptionId(int id);
    void setDestination(int folder, int afterChild);

    void start() Q_DECL_OVERRIDE;

private Q_SLOTS:
    void doMove();

private:
    int m_id;
    int m_destFolderId;
    int m_afterId;
    QWeakPointer<FeedList> m_feedList;
};

class AKREGATOR_EXPORT RenameSubscriptionJob : public KJob
{
    Q_OBJECT
public:
    explicit RenameSubscriptionJob(QObject *parent = nullptr);

    void setSubscriptionId(int id);
    void setName(const QString &name);

    void start() Q_DECL_OVERRIDE;

private Q_SLOTS:
    void doRename();

private:
    int m_id;
    QString m_name;
    QSharedPointer<FeedList> m_feedList;
};

class AKREGATOR_EXPORT DeleteSubscriptionJob : public KJob
{
    Q_OBJECT
public:
    explicit DeleteSubscriptionJob(QObject *parent = nullptr);

    void setSubscriptionId(int id);

    void start() Q_DECL_OVERRIDE;

private Q_SLOTS:
    void doDelete();

private:
    int m_id;
    QWeakPointer<FeedList> m_feedList;
};

}
#endif // AKREGATOR_SUBSCRIPTIONLISTJOBS_H

==> akregator-17.08.1.tar.xz: akregator-17.08.1/src/subscription/subscriptionlistjobs.h <==
/*
    This file is part of Akregator.

    Copyright (C) 2008 Frank Osterfeld <osterfeld@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

    As a special exception, permission is given to link this program
    with any edition of Qt, and distribute the resulting executable,
    without including the source code for Qt in the source distribution.
*/

#ifndef AKREGATOR_SUBSCRIPTIONLISTJOBS_H
#define AKREGATOR_SUBSCRIPTIONLISTJOBS_H

#include <KJob>

#include <QWeakPointer>

#include "akregator_export.h"

namespace Akregator {
class FeedList;

//transitional job classes

class AKREGATOR_EXPORT MoveSubscriptionJob : public KJob
{
    Q_OBJECT
public:
    explicit MoveSubscriptionJob(QObject *parent = nullptr);

    void setSubscriptionId(int id);
    void setDestination(int folder, int afterChild);

    void start() override;

private Q_SLOTS:
    void doMove();

private:
    int m_id;
    int m_destFolderId;
    int m_afterId;
    QWeakPointer<FeedList> m_feedList;
};

class AKREGATOR_EXPORT RenameSubscriptionJob : public KJob
{
    Q_OBJECT
public:
    explicit RenameSubscriptionJob(QObject *parent = nullptr);

    void setSubscriptionId(int id);
    void setName(const QString &name);

    void start() override;

private Q_SLOTS:
    void doRename();

private:
    int m_id;
    QString m_name;
    QSharedPointer<FeedList> m_feedList;
};

class AKREGATOR_EXPORT DeleteSubscriptionJob : public KJob
{
    Q_OBJECT
public:
    explicit DeleteSubscriptionJob(QObject *parent = nullptr);

    void setSubscriptionId(int id);

    void start() override;

private Q_SLOTS:
    void doDelete();

private:
    int m_id;
    QWeakPointer<FeedList> m_feedList;
};
}
#endif // AKREGATOR_SUBSCRIPTIONLISTJOBS_H
